@@ -221,6 +221,7 @@ G_BEGIN_DECLS
  * subscript. @Since: ATK-2.16.
  *@ATK_ROLE_SUPERSCRIPT: An object that contains text that is displayed as a
  * superscript. @Since: ATK-2.16.
+ *@ATK_ROLE_FOOTNOTE: An object that contains the text of a footnote. @Since: ATK-2.26.
  *@ATK_ROLE_LAST_DEFINED: not a valid role, used for finding end of the enumeration
  *
  * Describes the role of an object
@@ -353,6 +354,7 @@ typedef enum
   ATK_ROLE_MATH_ROOT,
   ATK_ROLE_SUBSCRIPT,
   ATK_ROLE_SUPERSCRIPT,
+  ATK_ROLE_FOOTNOTE,
   ATK_ROLE_LAST_DEFINED
 } AtkRole;
 
@@ -525,7 +527,7 @@ struct _AtkObject
  * @focus_event: The signal handler which is executed when there is a
  *   focus event for an object. This virtual function is deprecated
  *   since 2.9.4 and it should not be overriden. Use
- *   state-changed:focused signal instead.
+ *   the #AtkObject::state-change "focused" signal instead.
  */
 struct _AtkObjectClass
 {
